==> qore-0.8.13.7.tar.bz2: qore-0.8.13.7/docs/lang/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html",children:[
{text:"_",url:"namespacemembers.html#index__"},
{text:"a",url:"namespacemembers_a.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"i",url:"namespacemembers_i.html#index_i"},
{text:"j",url:"namespacemembers_j.html#index_j"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"u",url:"namespacemembers_u.html#index_u"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"x",url:"namespacemembers_x.html#index_x"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"Functions",url:"namespacemembers_func.html",children:[
{text:"a",url:"namespacemembers_func.html#index_a"},
{text:"b",url:"namespacemembers_func_b.html#index_b"},
{text:"c",url:"namespacemembers_func_c.html#index_c"},
{text:"d",url:"namespacemembers_func_d.html#index_d"},
{text:"e",url:"namespacemembers_func_e.html#index_e"},
{text:"f",url:"namespacemembers_func_f.html#index_f"},
{text:"g",url:"namespacemembers_func_g.html#index_g"},
{text:"h",url:"namespacemembers_func_h.html#index_h"},
{text:"i",url:"namespacemembers_func_i.html#index_i"},
{text:"j",url:"namespacemembers_func_j.html#index_j"},
{text:"k",url:"namespacemembers_func_k.html#index_k"},
{text:"l",url:"namespacemembers_func_l.html#index_l"},
{text:"m",url:"namespacemembers_func_m.html#index_m"},
{text:"n",url:"namespacemembers_func_n.html#index_n"},
{text:"o",url:"namespacemembers_func_o.html#index_o"},
{text:"p",url:"namespacemembers_func_p.html#index_p"},
{text:"r",url:"namespacemembers_func_r.html#index_r"},
{text:"s",url:"namespacemembers_func_s.html#index_s"},
{text:"t",url:"namespacemembers_func_t.html#index_t"},
{text:"u",url:"namespacemembers_func_u.html#index_u"},
{text:"v",url:"namespacemembers_func_v.html#index_v"},
{text:"x",url:"namespacemembers_func_x.html#index_x"},
{text:"y",url:"namespacemembers_func_y.html#index_y"}]},
{text:"Variables",url:"namespacemembers_vars.html",children:[
{text:"_",url:"namespacemembers_vars.html#index__"},
{text:"a",url:"namespacemembers_vars_a.html#index_a"},
{text:"b",url:"namespacemembers_vars_b.html#index_b"},
{text:"c",url:"namespacemembers_vars_c.html#index_c"},
{text:"d",url:"namespacemembers_vars_d.html#index_d"},
{text:"e",url:"namespacemembers_vars_e.html#index_e"},
{text:"f",url:"namespacemembers_vars_f.html#index_f"},
{text:"h",url:"namespacemembers_vars_h.html#index_h"},
{text:"i",url:"namespacemembers_vars_i.html#index_i"},
{text:"l",url:"namespacemembers_vars_l.html#index_l"},
{text:"m",url:"namespacemembers_vars_m.html#index_m"},
{text:"n",url:"namespacemembers_vars_n.html#index_n"},
{text:"o",url:"namespacemembers_vars_o.html#index_o"},
{text:"p",url:"namespacemembers_vars_p.html#index_p"},
{text:"r",url:"namespacemembers_vars_r.html#index_r"},
{text:"s",url:"namespacemembers_vars_s.html#index_s"},
{text:"t",url:"namespacemembers_vars_t.html#index_t"},
{text:"v",url:"namespacemembers_vars_v.html#index_v"},
{text:"w",url:"namespacemembers_vars_w.html#index_w"},
{text:"x",url:"namespacemembers_vars_x.html#index_x"},
{text:"z",url:"namespacemembers_vars_z.html#index_z"}]}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"inherits.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars.html#index_b"},
{text:"c",url:"functions_vars.html#index_c"},
{text:"d",url:"functions_vars.html#index_d"},
{text:"e",url:"functions_vars.html#index_e"},
{text:"f",url:"functions_vars.html#index_f"},
{text:"g",url:"functions_vars.html#index_g"},
{text:"h",url:"functions_vars.html#index_h"},
{text:"i",url:"functions_vars.html#index_i"},
{text:"l",url:"functions_vars.html#index_l"},
{text:"m",url:"functions_vars.html#index_m"},
{text:"n",url:"functions_vars.html#index_n"},
{text:"o",url:"functions_vars.html#index_o"},
{text:"p",url:"functions_vars.html#index_p"},
{text:"r",url:"functions_vars.html#index_r"},
{text:"s",url:"functions_vars.html#index_s"},
{text:"t",url:"functions_vars.html#index_t"},
{text:"u",url:"functions_vars.html#index_u"},
{text:"w",url:"functions_vars.html#index_w"},
{text:"y",url:"functions_vars.html#index_y"},
{text:"z",url:"functions_vars.html#index_z"}]}]}]}]}

==> qore-0.9.2.tar.bz2: qore-0.9.2/docs/lang/html/menudata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Related Pages",url:"pages.html"},
{text:"Modules",url:"modules.html"},
{text:"Namespaces",url:"namespaces.html",children:[
{text:"Namespace List",url:"namespaces.html"},
{text:"Namespace Members",url:"namespacemembers.html",children:[
{text:"All",url:"namespacemembers.html",children:[
{text:"_",url:"namespacemembers.html#index__"},
{text:"a",url:"namespacemembers_a.html#index_a"},
{text:"b",url:"namespacemembers_b.html#index_b"},
{text:"c",url:"namespacemembers_c.html#index_c"},
{text:"d",url:"namespacemembers_d.html#index_d"},
{text:"e",url:"namespacemembers_e.html#index_e"},
{text:"f",url:"namespacemembers_f.html#index_f"},
{text:"g",url:"namespacemembers_g.html#index_g"},
{text:"h",url:"namespacemembers_h.html#index_h"},
{text:"i",url:"namespacemembers_i.html#index_i"},
{text:"j",url:"namespacemembers_j.html#index_j"},
{text:"k",url:"namespacemembers_k.html#index_k"},
{text:"l",url:"namespacemembers_l.html#index_l"},
{text:"m",url:"namespacemembers_m.html#index_m"},
{text:"n",url:"namespacemembers_n.html#index_n"},
{text:"o",url:"namespacemembers_o.html#index_o"},
{text:"p",url:"namespacemembers_p.html#index_p"},
{text:"r",url:"namespacemembers_r.html#index_r"},
{text:"s",url:"namespacemembers_s.html#index_s"},
{text:"t",url:"namespacemembers_t.html#index_t"},
{text:"u",url:"namespacemembers_u.html#index_u"},
{text:"v",url:"namespacemembers_v.html#index_v"},
{text:"w",url:"namespacemembers_w.html#index_w"},
{text:"x",url:"namespacemembers_x.html#index_x"},
{text:"y",url:"namespacemembers_y.html#index_y"},
{text:"z",url:"namespacemembers_z.html#index_z"}]},
{text:"Functions",url:"namespacemembers_func.html",children:[
{text:"a",url:"namespacemembers_func.html#index_a"},
{text:"b",url:"namespacemembers_func_b.html#index_b"},
{text:"c",url:"namespacemembers_func_c.html#index_c"},
{text:"d",url:"namespacemembers_func_d.html#index_d"},
{text:"e",url:"namespacemembers_func_e.html#index_e"},
{text:"f",url:"namespacemembers_func_f.html#index_f"},
{text:"g",url:"namespacemembers_func_g.html#index_g"},
{text:"h",url:"namespacemembers_func_h.html#index_h"},
{text:"i",url:"namespacemembers_func_i.html#index_i"},
{text:"j",url:"namespacemembers_func_j.html#index_j"},
{text:"k",url:"namespacemembers_func_k.html#index_k"},
{text:"l",url:"namespacemembers_func_l.html#index_l"},
{text:"m",url:"namespacemembers_func_m.html#index_m"},
{text:"n",url:"namespacemembers_func_n.html#index_n"},
{text:"o",url:"namespacemembers_func_o.html#index_o"},
{text:"p",url:"namespacemembers_func_p.html#index_p"},
{text:"r",url:"namespacemembers_func_r.html#index_r"},
{text:"s",url:"namespacemembers_func_s.html#index_s"},
{text:"t",url:"namespacemembers_func_t.html#index_t"},
{text:"u",url:"namespacemembers_func_u.html#index_u"},
{text:"v",url:"namespacemembers_func_v.html#index_v"},
{text:"x",url:"namespacemembers_func_x.html#index_x"},
{text:"y",url:"namespacemembers_func_y.html#index_y"}]},
{text:"Variables",url:"namespacemembers_vars.html",children:[
{text:"_",url:"namespacemembers_vars.html#index__"},
{text:"a",url:"namespacemembers_vars_a.html#index_a"},
{text:"b",url:"namespacemembers_vars_b.html#index_b"},
{text:"c",url:"namespacemembers_vars_c.html#index_c"},
{text:"d",url:"namespacemembers_vars_d.html#index_d"},
{text:"e",url:"namespacemembers_vars_e.html#index_e"},
{text:"f",url:"namespacemembers_vars_f.html#index_f"},
{text:"h",url:"namespacemembers_vars_h.html#index_h"},
{text:"i",url:"namespacemembers_vars_i.html#index_i"},
{text:"l",url:"namespacemembers_vars_l.html#index_l"},
{text:"m",url:"namespacemembers_vars_m.html#index_m"},
{text:"n",url:"namespacemembers_vars_n.html#index_n"},
{text:"o",url:"namespacemembers_vars_o.html#index_o"},
{text:"p",url:"namespacemembers_vars_p.html#index_p"},
{text:"r",url:"namespacemembers_vars_r.html#index_r"},
{text:"s",url:"namespacemembers_vars_s.html#index_s"},
{text:"t",url:"namespacemembers_vars_t.html#index_t"},
{text:"v",url:"namespacemembers_vars_v.html#index_v"},
{text:"w",url:"namespacemembers_vars_w.html#index_w"},
{text:"x",url:"namespacemembers_vars_x.html#index_x"},
{text:"z",url:"namespacemembers_vars_z.html#index_z"}]}]}]},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"inherits.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"_",url:"functions.html#index__"},
{text:"a",url:"functions_a.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"},
{text:"y",url:"functions_y.html#index_y"},
{text:"z",url:"functions_z.html#index_z"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"e",url:"functions_func_e.html#index_e"},
{text:"f",url:"functions_func_f.html#index_f"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"h",url:"functions_func_h.html#index_h"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"j",url:"functions_func_j.html#index_j"},
{text:"k",url:"functions_func_k.html#index_k"},
{text:"l",url:"functions_func_l.html#index_l"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"o",url:"functions_func_o.html#index_o"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"v",url:"functions_func_v.html#index_v"},
{text:"w",url:"functions_func_w.html#index_w"},
{text:"y",url:"functions_func_y.html#index_y"},
{text:"z",url:"functions_func_z.html#index_z"}]},
{text:"Variables",url:"functions_vars.html",children:[
{text:"_",url:"functions_vars.html#index__"},
{text:"a",url:"functions_vars.html#index_a"},
{text:"b",url:"functions_vars.html#index_b"},
{text:"c",url:"functions_vars.html#index_c"},
{text:"d",url:"functions_vars.html#index_d"},
{text:"e",url:"functions_vars.html#index_e"},
{text:"f",url:"functions_vars.html#index_f"},
{text:"g",url:"functions_vars.html#index_g"},
{text:"h",url:"functions_vars.html#index_h"},
{text:"i",url:"functions_vars.html#index_i"},
{text:"l",url:"functions_vars.html#index_l"},
{text:"m",url:"functions_vars.html#index_m"},
{text:"n",url:"functions_vars.html#index_n"},
{text:"o",url:"functions_vars.html#index_o"},
{text:"p",url:"functions_vars.html#index_p"},
{text:"r",url:"functions_vars.html#index_r"},
{text:"s",url:"functions_vars.html#index_s"},
{text:"t",url:"functions_vars.html#index_t"},
{text:"u",url:"functions_vars.html#index_u"},
{text:"w",url:"functions_vars.html#index_w"},
{text:"y",url:"functions_vars.html#index_y"},
{text:"z",url:"functions_vars.html#index_z"}]}]}]}]}
